/*
This jQuery App is designed to filter and display a
list of snowboards based on user selected criteria.
*/

// Actions taken when Find button is clicked.
$(document).ready(function(){
    $("#find").click(function(){
        findBoards();
    });
});

// Actions taken when Reset button is clicked.
$(document).ready(function(){
    $("#reset").click(function(){
        // Reset default Values of the form elements.
        $("#ability").val("All");
        $("input[value='All']").prop('checked', true); // Reset Gender default to All.
        $("#style").val("All");
        $("#waist").val("All");
        $("#weight").val("");
        $("#finder-results").html("");
    });
});

// Function to Find Snowboard
function findBoards() {
    // Set Variables
    var ability = $("#ability").val();
    var gender = $("input[name='gender']:checked").val();
    var style = $("#style").val();
    var waist = $("#waist").val();
    var weight = $("#weight").val();
    
    // Weight Error Check
    if (isNaN(weight)) {
        alert("The finder app only accepts a numerical weight between 0 and 999 without any decimals.");
        return; // exit Find Function
    }

    // Fetch Snowboards
    $.getJSON("data/snowboards.json", function(data){

        // Variables
        var found = 0;
        var boardResults = "";
        var plural = '';
        var snowboard = data.snowboards;
        // Set test variables to find a keyword in a multiple value field. 'i' instructs to ignore typing case.
        var regAb = RegExp(ability, 'i'); 
        var regSt = RegExp(style, 'i');

        // Find Snowboards Matching Criteria and Generate HTML
        $.each(snowboard, function(i, value){
            if ((ability == 'All' || regAb.test(snowboard[i].ability)) &&
                (style == 'All' || regSt.test(snowboard[i].style)) &&  
                (gender == 'All' || gender == snowboard[i].gender) && 
                (weight == '' || testWeight(Number(weight), Number(snowboard[i].weightMin), Number(snowboard[i].weightMax))) &&
                (waist == 'All' || waist == snowboard[i].waist)) {
                
                //    $("#finder-results").append('<p>' + i + value.name + '</p>');

                boardResults += '<tr>' +
                                    '<td class="finder-table-td">' + snowboard[i].brand + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].name + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].camber + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].ability + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].style + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].gender + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].lengthCM + '</td>' +
                                    '<td class="finder-table-td">' + snowboard[i].waist + '</td>' +
                                    '<td class="finder-table-td">' + displayWeight(snowboard[i].weightMin, snowboard[i].weightMax) + '</td>' +
                                    '</tr>';
                    found++;
            }

        });

        if (found > 0) { // Display boards found in a table.
            // Snowboard requires an 's' if multiple boards are found.
            if (found > 1) {
                plural += 's were';
            } else {
                plural += ' was';
            }
            var resultsHeader = '<p class="p-finder-count">' + found + ' snowboard' + plural + ' found.</p>' +
                                '<table id="finderTable" class="tablesorter">' +
                                '<thead><tr>' +
                                '<th class="finder-table-th">Brand</th>' +
                                '<th class="finder-table-th">Name</th>' +
                                '<th class="finder-table-th">Camber</th>' +
                                '<th class="finder-table-th">Ability</th>' + 
                                '<th class="finder-table-th">Style</th>' +
                                '<th class="finder-table-th">Gender</th>' +
                                '<th class="finder-table-th">Length (cm)</th>' +
                                '<th class="finder-table-th">Waist</th>' +
                                '<th class="finder-table-th">Range (lbs)</th>' +
                                '</tr></thead>';
            var resultsFooter = '</table>';
            $("#finder-results").html(resultsHeader + boardResults + resultsFooter);

            // Set the table to sortable.
            // jQuery Plugin by Christian Bach and Rob G: https://mottie.github.io/tablesorter/
            $(function() {
                $("#finderTable").tablesorter({
                    // Set Tablesorter theme.
                    theme: 'blue',
                    // Set Initial Sort
                    sortList: [0,1] // Initial sort, first column ascending.
                });
            });

        } else { // If no boards are found.
            boardResults += '<p class="p-finder-count">No boards were found matching your search criteria.</p>';
            $("#finder-results").html(boardResults);
        }
        
        // Function to Format a Board's Weight Range for Display
        function displayWeight(min, max) {
            var weightHtml = '';
            if (!min) { // If no minimum weight range.
                weightHtml += 'Up to ' + max;
            } else if (!max) { // If no maximum weight range.
                weightHtml += min + ' +';
            } else {
                weightHtml += min + ' - ' + max;
            }
            return weightHtml;
        }

        // Function to Find Boards according to rider's weight.
        function testWeight(riderWeight, boardMin, boardMax) {
            if ((riderWeight >= boardMin && riderWeight <= boardMax) ||// Test if weight is within range.
                (!boardMin && riderWeight <= boardMax) || // If there is no minimum weight, rider must be less or equal to max weight.
                (!boardMax && riderWeight >= boardMin)) { // If there is no maximum weight, rider must be equal to or more than min weight.
                return true;
            } else {
                return false;
            }
        }

        
    });
}